excerpts: excerpts.ui Namespace Reference

excerpts

- Main Page
- Packages
- Files

- Packages
- Package Functions

All Namespaces Files Functions
Functions
excerpts.ui Namespace Reference

## Functions
def | excerpts
| Extract, Convert and Save Markdown Style Comments From a File. More...

## Function Documentation

def excerpts.ui.excerpts | ( |  | file_name,
|  |  | comment_character = `"#"`,
|  |  | magic_character = `"%"`,
|  |  | allow_pep8 = `True`,
|  |  | output_path = `""`,
|  |  | prefix = `""`,
|  |  | postfix = `""`,
|  |  | run_pandoc = `True`,
|  |  | compile_latex = `False`,
|  |  | pandoc_formats = `"tex"`
| ) |  |

Extract, Convert and Save Markdown Style Comments From a File.

This is merely a wrapper to excerpt(), modify_path() and pandoc().

Parameters

  file_name | The file from which the lines are to be extracted.
  comment_character | The comment character of the files language.
  magic_character | The magic character marking lines as excerpts.
  allow_pep8 | Remove a leading single comment character and blank.
  output_path | Set a new file name or an output directory.
  postfix | Set the output file postfix.
  prefix | Set the output file prefix.
  run_pandoc | Run pandoc on the markdown file created?
  compile_latex | Compile the LaTeX file?
  pandoc_formats | The pandoc output formats to be used.

Returns
  0 if output generation was successful, 1 otherwise.